@@ -85,10 +85,8 @@ class erstruct:
 
 class Gene_sample:
     def download_sample(self):
-        data1 = np.load('../data/char21.npy')
-        data2 = np.load('../data/char22.npy')
-        #data1 = pkg_resources.resource_string(__name__, '../data/char21.npy')
-        #data2 = pkg_resources.resource_string(__name__, '../data/char22.npy')
+        data1 = pkg_resources.resource_string("ERStruct", 'data/char21.npy')
+        data2 = pkg_resources.resource_string("ERStruct", 'data/char22.npy')
         np.save('sample_data/char21.npy', data1)
         np.save('sample_data/char22.npy', data2)
 
